.. _user_guide_exploring_a_dataframe_index:

Exploring a Dataframe
=====================

This section covers the :class:`~skrub.TableReport` and how it can be used for exploring
and understanding your dataframes.


.. toctree::
   :maxdepth: 3

   modules/tablereport/exploring_dataframes_interactively
   modules/tablereport/finding_correlated_columns
